@@ -76,7 +76,7 @@ from operator import attrgetter
 from compiler.visitor import ASTVisitor
 
 
-__version__ = '1.2.12'
+__version__ = '1.2.13'
 
 
 def adjust_lineno(filename, lineno, name):
@@ -483,6 +483,10 @@ class ModuleGraph(object):
             pass
         for dir in self.path:
             if os.path.isfile(dir):
+                if dir.endswith('.egg-info'):
+                    # distribute creates a setuptools-blah-blah.egg-info
+                    # that ends up in sys.path
+                    continue
                 try:
                     zf = zipfile.ZipFile(dir)
                 except zipfile.BadZipfile:
